function initCompressor3()

global poly_c0  poly_c1 poly_c2 poly_c3 R M T1

compressorData = zeros(6,6,2);

%Measured speed lines arrays, transformed to rad/s and volumetric flow m3/s for given inlet pressure

Z = 1;%0.891;       % Compressibility
P = 32.2e5;         % Pressure, Pa

compressorData(:,1,1) = [9190 9803 11029 12014 12254 12867]/60*2*pi;    % Speed lines
compressorData(:,1,2) = [9190 9803 11029 12014 12254 12867]/60*2*pi;    % Speed lines

compressorData(1,2:end,1) = [-1000 0 1400 1800 2200]/3600; %Correspoding flow data for 1st speed line
compressorData(1,2:end,2) = [2.1 0.75 1.9 1.75 1.42]; %Correspoding pressure ratio data for 1st speed line

compressorData(2,2:end,1) = [-1000 0 1400 2000 2400]/3600; %Correspoding flow data for 2nd speed line
compressorData(2,2:end,2) = [2.6 0.9 2.15 1.85 1.5]; %Correspoding pressure ratio data for 2nd speed line

compressorData(3,2:end,1) = [-1000 0 1600 2200 2800]/3600; %Correspoding flow data for 3rd speed line
compressorData(3,2:end,2) = [3 1.15 2.55 2.3 1.7]; %Correspoding pressure ratio data for 3rd speed line

compressorData(4,2:end,1) = [-1000 0 1800 2600 3200]/3600; %Correspoding flow data for 4th speed line
compressorData(4,2:end,2) = [3.5 1.3 3 2.6 1.75]; %Correspoding pressure ratio data for 4th speed line

compressorData(5,2:end,1) = [-1000 0 2000 2600 3200]/3600; %Correspoding flow data for 5th speed line
compressorData(5,2:end,2) = [3.75 1.5 3.1 2.75 1.85]; %Correspoding ratio pressure data for 5th speed line

compressorData(6,2:end,1) = [-1000 0 2200 2800 3400]/3600; %Correspoding flow data for 6th speed line
compressorData(6,2:end,2) = [4.25 2 3.35 2.9 1.85]; %Correspoding pressure ratio data for 6th speed line

% Fit measurement to speed line polynomials
poly_n1 = polyfit(compressorData(1,2:end,1),compressorData(1,2:end,2),3); %polynomial for 1st speed line
poly_n2 = polyfit(compressorData(2,2:end,1),compressorData(2,2:end,2),3); %polynomial for 2nd speed line
poly_n3 = polyfit(compressorData(3,2:end,1),compressorData(3,2:end,2),3); %polynomial for 3rd speed line
poly_n4 = polyfit(compressorData(4,2:end,1),compressorData(4,2:end,2),3); %polynomial for 4th speed line
poly_n5 = polyfit(compressorData(5,2:end,1),compressorData(5,2:end,2),3); %polynomial for 5th speed line
poly_n6 = polyfit(compressorData(6,2:end,1),compressorData(6,2:end,2),3); %polynomial for 6th speed line

poly_matrix = [poly_n1;poly_n2;poly_n3;poly_n4;poly_n5;poly_n6];

% Fit calculated speed line polynomial coefficients to 3rd order
% coefficient polynomial 
[coeff_c3 e3 mu_3] = polyfit(compressorData(:,1,1),poly_matrix(:,1),3);
[coeff_c2 e2 mu_2]= polyfit(compressorData(:,1,1),poly_matrix(:,2),3);
[coeff_c1 e1 mu_1]= polyfit(compressorData(:,1,1),poly_matrix(:,3),3);
[coeff_c0 e0 mu_0]= polyfit(compressorData(:,1,1),poly_matrix(:,4),3);

poly_c3 = struct('coeff',coeff_c3,'est',e3,'mu',mu_3);
poly_c2 = struct('coeff',coeff_c2,'est',e2,'mu',mu_2);
poly_c1 = struct('coeff',coeff_c1,'est',e1,'mu',mu_1);
poly_c0 = struct('coeff',coeff_c0,'est',e0,'mu',mu_0);

% 2D plot of compressor map
flows = -1000*P*M/(Z*R*T1)/3600:1:3600*P*M/(Z*R*T1)/3600;
speeds = [9190 9803 11029 12014 12254 12867]/60*2*pi;
gains = zeros(1,length(flows));

figure;
hold all;
clm = colormap('lines');

plot(flows/(P*M/(Z*R*T1)),SCLinv(flows/(P*M/(Z*R*T1))),'k');

for i=1:length(speeds)
    for j=1:length(flows)
       gains(j) = compressorMap3(speeds(i),flows(j),P);
    end
    plot(flows/(P*M/(Z*R*T1)),gains,'Color',clm(i,:));
end

for i=1:size(compressorData,1)
   plot(compressorData(i,2:end,1),compressorData(i,2:end,2),'--+','Color',clm(i,:)); 
end

legend('SCL',num2str(speeds(1)),num2str(speeds(2)),num2str(speeds(3)),num2str(speeds(4)),num2str(speeds(5)),num2str(speeds(6)),'Location','Best');

