global a1 a2 a3 a4 a5 a6 a7  Kp_s Kd_s Ki_s Kp_r Kd_r Ki_r J r_r k_scl wf pa R M T1 omega_d lre qe Re ue strategy

% Gas and temperature specific constants
c_gas = 400.97;                             % Speed of sound in gas, m/s
M = 22e-3;                                  % Gas molar mass, kg/mol
R = 8.314472;                               % Universal gas constant, J/(mol * K)
T1 = 22 + 273.16;                           % Absolute gas temperature, K, volume 1
T2 = 109 + 273.16;                          % Absolute gas temperature, K, volume 2
C_r_star = 110*27.8e-6;                     % Derived from recycle valve data sheet, given CV = 110 (corresponds to K_v in valve selection handbook)
C_r = C_r_star*sqrt(2*M/(R*T2));            % Modified recycle valve constant, for mass flow
V1 = 3.3;                                   % Compressor upstream volume, m^3
V2 = 0.1;                                   % Compressor downstream volume, m^3
L_c = 10;                                   % Compressor duct length, m
A_c = 0.5;                                  % Compressor duct cross section area, m^2
L_r = 50;                                   % Recycle duct length, m
A_r = 0.5;   	                            % Recycle duct cross section area, m^2
L_t = 100;   	                            % Check valve duct length, m
A_t = 0.5;                                  % Check valve duct cross section area, m^2
J = 2;                                      % Compressor inertia
r_r = 0.079;                                % Rotor radius

cqw = R*T1/M;
k1 = 1;                                     % Help variable for check valve saturation

% Constants
a1 = c_gas^2/V1;                            % Inlet volume
a2 = c_gas^2/V2;                            % Outlet volume
a3 = A_c/L_c;                               % Compressor gain
a4 = A_r/L_r;                               % Recycle line gain
a5 = A_t/L_t;                               % Throttle flow gain
a6 = 1/C_r^2;                               % Recycle valve gain
a7 = cqw;      

% Speed controller parameters
Kp_s = 0.2;
Kd_s = 0;
Ki_s = 0.01;

% Recycle valve controller parameters
Kp_r = 20;
Kd_r = 0;    %Kd_r = 0.000043;
Ki_r = 10;

% Disturbances
wf = 7;         % Feed mass flow
pa = 4e6;       % Downstream pressure

% Set points
omega_d = 1100;

% Surge control line and strategy
k_scl = 0.6;
strategy = 1;

initCompressor3();

% Input pulse
step_feed = 0;
step_valve = 0;

% Equilibria
o = optimset('TolFun',1e-8,'Diagnostics','off');

qe = fsolve(@eq_fun,wf*4*R*T1/M/pa,o);
Re = SCLinv(qe);
p1e = pa/Re;
p2e = pa;
wce = pa*qe/a7/Re;
wre = pa*qe/a7/Re - wf;
wte = wf;
ue = (pa*qe/a7/Re - wf)^2/(pa^2*(1-1/Re));
lre = sqrt(a6*ue);

% Initial values
w0 = wf;            % Mass flow
p10 = p1e;          % Inlet pressure
p20 = p2e;          % Outlet pressure
omega0 = omega_d;   % Speed

